*replication file for:
*--------------------------
*Gschwend, Thomas, and Dirk Leuffen. 2005. Divided We Stand - Unified We Govern? The Issue of Cohabitation in the French Elections of 2002.
*British Journal of Political Science 35(4): 691-712. 


* please specify diretory on your machine where "replication_GschwendLeuffen2005.dta" can be found"

* this dofile requires following ado-packages:

* - Triplot ("ssc inst triplot, replace")
* - Clarify ("net from http://gking.harvard.edu/clarify/
*		 "net install clarify")



version 9.0

set more off
 
*Install "

use replication_GschwendLeuffen2005.dta, clear

*table 1
mlogit wahl1 lrself candidate rechts links ambivalent reinst liinst ambcohab economy security , b(2) robust
gen esample=e(sample)

eststo est1
esttab using example2.rtf, replace nostar brackets label title (Distangling Regime from Anchoring Preferences: A MNL Vote Choice Model of the French Parliamentary Election 2002) nonumbers eqlabel ("Others vs. Right" "Left vs. Right") mtitles (.) cells("se(fmt(3)) b p") unstack


*table 2

set seed 11111
estsimp mlogit wahl1 lrself rechts links ambivalent reinst liinst ambcohab candidate economy security, b(2) robust


*for the Left Favour Cahabitation
setx 0
setx lrself mean candidate mean economy mean security mean links 1
simqi, prval(1)



*for the Left Oppose Cohabitation
setx liinst 1
simqi, prval(1) 
setx 0
setx lrself mean candidate mean economy mean security mean links 1
simqi, fd(prval(0)) changex(liinst 0 1) 


*for the Right Favour Cohabitation
setx 0
setx lrself mean candidate mean economy mean security mean rechts 1
simqi, prval(2) 


*for the Right Oppose Cohabitation
setx reinst 1
simqi, prval(2)
setx 0
setx lrself mean candidate mean economy mean security mean rechts 1
simqi, fd(prval(2)) changex(reinst 0 1)


capture drop b*


*Figure2. Stimulated influence of attitudes towards cohabition on vote choice for supporters of the left
*Triplot-Simulations

set seed 11111
estsimp mlogit wahl1 lrself rechts links ambivalent reinst liinst ambcohab candidate economy security, sims(100) b(2) robust

setx 0
setx lrself mean candidate mean economy mean security mean
setx links 1 
simqi, prval(0 1 2) listx genpr(li0 li1 li2)
setx liinst 1
simqi, prval(0 1 2) listx genpr(liinst0 liinst1 liinst2) 

triplot6 li0 li2 li1, label(.) y ltext(" ") rtext(" ") btext(" ") bltext("Left") brtext("Right") ttext("Other")


*Figure3
*Triplot-Simulations

setx 0
setx lrself mean candidate mean economy mean security mean
setx rechts 1 
simqi, prval(0 1 2) listx genpr(re0 re1 re2) 
setx reinst 1
simqi, prval(0 1 2) listx genpr(reinst0 reinst1 reinst2)

triplot6 re0 re2 re1, label(.) y ltext(" ") rtext(" ") btext(" ") bltext("Left") brtext("Right") ttext("Other")


*Figure4
*Triplot-Simulations

setx 0
setx lrself mean candidate mean economy mean security mean
setx ambivalent 1 
simqi, prval(0 1 2) listx genpr(am0 am1 am2) 
setx ambcohab 1
simqi, prval(0 1 2) listx genpr(aminst0 aminst1 aminst2) 

triplot6 am0 am2 am1, label(.) y ltext(" ") rtext(" ") btext(" ") bltext("Left") brtext("Right") ttext("Other")

*Table 3

*Scenario 1, Spporter of the political right, moderate/right ideologically: oppose cohab
setx 0
setx lrself mean candidate mean economy mean security mean
setx rechts 1 
simqi, prval(1)

setx lrself 1 
simqi, prval(1)

*Scenario 1, Spporter of the political right, moderate/right ideologically: favor cohab
setx 0
setx lrself mean candidate mean economy mean security mean reinst 1
setx rechts 1 
simqi, prval(1)

setx lrself 1 
simqi, prval(1)




*Scenario 2, Spporter of the political left, moderate/left ideologically: oppose cohab
setx 0
setx lrself mean candidate mean economy mean security mean liinst 1
setx links 1 
simqi, prval(2)

setx lrself 0 
simqi, prval(2) 

*Scenario 2, Spporter of the political left, moderate/left ideologically: favor cohab
setx 0
setx lrself mean candidate mean economy mean security mean
setx links 1 
simqi, prval(2)

setx lrself 0 
simqi, prval(2) 

*Appendix

sum lrself candidate rechts links ambivalent reinst liinst ambcohab economy security if esample
